"use strict"
exports.__esModule = true;
exports.SeverityUndefinedIconConfig = {
  name: 'SeverityUndefinedIcon',
  height: 1024,
  width: 1024,
  svgPath: "M640,384h320c35.3,0,64,28.7,64,64v64c0,35.3-28.7,64-64,64h-320c-35.3,0-64-28.7-64-64v-64c0-35.3,28.7-64,64-64ZM64,384h320c35.3,0,64,28.7,64,64v64c0,35.3-28.7,64-64,64H64c-35.3,0-64-28.7-64-64v-64c0-35.3,28.7-64,64-64Z",
  yOffset: 0,
  xOffset: 0,
  svgClassName: undefined,
};
exports.SeverityUndefinedIcon = require('../createIcon').createIcon(exports.SeverityUndefinedIconConfig);
exports["default"] = exports.SeverityUndefinedIcon;